import { RouterService, StorageService } from '@lightweightform/core';
import { ValidationError } from '@lightweightform/storage';
import { MarkdownService } from 'ngx-markdown';
/**
 * Service used to format validation messages' to HTML messages
 */
export declare class ValidationMessagesService {
    protected _storageService: StorageService;
    protected _routerService: RouterService;
    protected _markdownService: MarkdownService;
    constructor(_storageService: StorageService, _routerService: RouterService, _markdownService: MarkdownService);
    /**
     * Formats a validation error message assuming the Markdown standard
     * specification. Applies some pre processors, such as:
     * - labelLink pre-processor: converts a tag with format "@${path}@" to a
     * hyperlink to the given path and a message specified in that path's
     * component.
     * @param validationError Validation error with the preformatted message.
     * @returns Formatted message.
     */
    formatMessage(validationError: ValidationError): string;
    /**
     * Gets the label associated to the given path.
     * @param path Path from which to fetch label.
     * @returns Label of given path.
     */
    getLabel(path: any): string;
    protected _parseMD(message: string): string;
    protected _applyPreProcessors(message: any): any;
    protected _preProcessorLabelLinks(message: any): any;
}
